@@ -1,25 +1,22 @@
 #![cfg(feature = "auto-increment")]
-use {
-	crate::{data::schema::ColumnDefExt, executor::types::Row, Result, StorageInner, Value},
-	sqlparser::ast::ColumnDef,
-};
+use crate::{Column, Result, Row, StorageInner, Value, ValueDefault};
 
 pub async fn auto_increment(
 	storage: &mut StorageInner,
 	table_name: &str,
-	column_defs: &[ColumnDef],
-	rows: Vec<Row>,
-) -> Result<Vec<Row>> {
-	let auto_increment_columns = column_defs
+	columns: &[Column],
+	rows: &mut [Row],
+) -> Result<()> {
+	let auto_increment_columns = columns
 		.iter()
 		.enumerate()
-		.filter(|(_, column_def)| column_def.is_auto_incremented())
-		.map(|(index, column_def)| {
+		.filter(|(_, column)| matches!(column.default, Some(ValueDefault::AutoIncrement(_))))
+		.map(|(index, column)| {
 			(
 				index,
-				column_def.name.value.clone(),
+				column.name.clone(),
 				rows.iter()
-					.filter(|row| matches!(row.get(index), Some(Value::Null)))
+					.filter(|row| matches!(row.0.get(index), Some(Value::Null)))
 					.count() as i64,
 			)
 		})
@@ -29,17 +26,15 @@ pub async fn auto_increment(
 		.generate_increment_values(table_name.to_string(), auto_increment_columns)
 		.await?;
 
-	let mut rows = rows;
 	let mut column_values = column_values;
-	for row in &mut rows {
+	for row in rows.iter_mut() {
 		for ((index, _name), value) in &mut column_values {
-			let cell = row.get_mut(*index).unwrap();
+			let cell = row.0.get_mut(*index).unwrap();
 			if matches!(cell, Value::Null) {
 				*cell = Value::I64(*value);
-
 				*value += 1;
 			}
 		}
 	}
-	Ok(rows)
+	Ok(())
 }
