@@ -8,7 +8,8 @@ use {
 	},
 	futures::executor::block_on,
 	sqlparser::ast::{
-		Expr, Ident, ObjectName, Query as AstQuery, SetExpr, Statement, Value as AstValue, Values,
+		Expr, Ident, ObjectName, ObjectType, Query as AstQuery, SetExpr, Statement,
+		Value as AstValue, Values,
 	},
 	std::{collections::HashMap, fmt::Debug},
 };
@@ -123,6 +124,15 @@ impl Glue {
 	}
 }
 
+impl Glue {
+	pub fn into_connections(self) -> Vec<(String, Connection)> {
+		self.storages
+			.into_iter()
+			.map(|(name, storage)| (name, storage.into_source()))
+			.collect()
+	}
+}
+
 /// ## Execute (Generic)
 impl Glue {
 	/// Will execute a single query.
@@ -160,7 +170,7 @@ impl Glue {
 				match location {
 					None => Err(ExecuteError::InvalidDatabaseLocation.into()), // TODO: Memory
 					Some(location) => {
-						let store = if location.ends_with("/") {
+						let store = if location.ends_with('/') {
 							Connection::Sled(location).try_into()?
 						} else if location.ends_with(".csv") {
 							Connection::CSV(location, CSVSettings::default()).try_into()?
@@ -172,6 +182,46 @@ impl Glue {
 					}
 				}
 			};
+		} else if let Query(Statement::Execute { name, parameters }) = query {
+			return match name.value.as_str() {
+				"FILE" => {
+					if let Some(Ok(query)) = parameters.get(0).map(|path| {
+						if let Expr::Value(AstValue::SingleQuotedString(path)) = path {
+							std::fs::read_to_string(path).map_err(|_| ())
+						} else {
+							Err(())
+						}
+					}) {
+						self.execute(&query)
+					} else {
+						Err(ExecuteError::InvalidFileLocation.into())
+					}
+				}
+				_ => Err(ExecuteError::Unimplemented.into()),
+			};
+		} else if let Query(Statement::Drop {
+			object_type: ObjectType::Schema, // FOR NOW! // TODO: sqlparser-rs#454
+			if_exists,
+			names,
+			..
+		}) = query
+		{
+			let database_name = names
+				.get(0)
+				.and_then(|name| name.0.get(0).map(|name| name.value.clone()))
+				.ok_or(ExecuteError::ObjectNotRecognised)?;
+
+			let index = self
+				.storages
+				.iter()
+				.enumerate()
+				.find_map(|(index, (name, _))| (name == &database_name).then(|| index));
+			if let Some(index) = index {
+				self.storages.remove(index);
+			} else if !if_exists {
+				return Err(ExecuteError::ObjectNotRecognised.into());
+			}
+			return Ok(Payload::Success);
 		}
 
 		let mut storages: Vec<(String, Box<StorageInner>)> = self
