@@ -7,3 +7,8 @@ pub use sled_storage::SledStorage;
 mod csv_storage;
 #[cfg(feature = "csv-storage")]
 pub use csv_storage::{CSVSettings, CSVStorage, CSVStorageError};
+
+#[cfg(feature = "sheet-storage")]
+mod sheet_storage;
+#[cfg(feature = "sheet-storage")]
+pub use sheet_storage::{SheetStorage, SheetStorageError};
